breed [agents agent]
breed [governments government]
directed-link-breed [active-links active-link]

globals [

;; System Constants

  ;DT ;;This is "difference in time" or "delta time". Delta time is used as an approximation of "derivative of time"
   ;;to iterate Euler integration forward.
   

;; All Others
  
  Government_Commitment_To_Repression
  Max_Government_Strength
  Max_Grievance
  Max_Participation
  Max_Repression
  Min_Government_Strength_Adj_Time
  Min_Grievance_Adj_Time
  Min_Participation_Adj_Time

;;Reporting
total-government-strength
total-grievance
total-participation
total-severity
total-effectiveness 

]

governments-own [
  
  ;;Constants
  Initial_Government_Strength

  ;;Auxiliaries
  
  Govt_Strength_Decr_From_Political_Action
  Max_Govt_Strength_Decr
  Repression
  
  Total_Severity_Of_Political_Action
  Total_Effectiveness_Of_Political_Action
  
  ;;Flows
  Government_Strength_Increase
  Government_Strength_Decrease

  ;;Stocks
  Government_Strength

]

agents-own [
  active

  ;;Constants
  Initial_Grievance
  Initial_Participation
  Initial_Perc_Eff_Of_Political_Action
  
  A_Nrm_Grievance_Decay_Time
  A_Participation_Decay_Time
  A_Normal_Frustration_Time
  A_Effectiveness_Learning_Time

  ;; Network Diffusion Auxiliaries

  Effect_Of_Seeing_Others_Participation 
  Effect_Of_Sharing_Grievances
  Effectiveness_Of_Political_Action_By_Others

  ;; Auxiliaries

  Total_Government_Strength
  Total_Repression 

  Effectiveness_Of_Political_Action
  Frustration_Reinforcement_Rate
  Grievance_Decay_Time
  Grievance_Incr_From_Repression
  Max_Grievance_Increase
  Max_Participation_Incr
  Participation_Incr_From_Grievance
  Potential_For_Political_Action
  Severity_Of_Political_Action


  ;;Flows
  Grievance_Increase
  Grievance_Decrease
  
  Participation_Increase
  Participation_Decrease
  
  Learning_Eff_Of_Political_Action
  
  ;;Stocks
  Grievance
  Participation
  Perceived_Effectiveness_Of_Political_Action

]



patches-own [
  neighborhood        ; surrounding patches within the vision radius
]

active-links-own [
  current-flow        ; the amount of grievance, shared through a link in a given step
]  

to setup
  ;; (for your model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks
  
  ;; SET GLOBALS
  set-default-shape agents "circle"
  set-default-shape links "small-arrow-link"
  
  ask patches [
    ;; make background a slightly dark gray
    set pcolor gray - 1
    ;; cache patch neighborhoods
    set neighborhood patches in-radius vision
  ]

;; SET GLOBAL CONSTANTS

;; System Constants

set DT 0.25 ;;This is "difference in time" or "delta time". Delta time is used as an approximation of "derivative of time"
              ;;to iterate Euler integration forward. Too large a value will produce artifacts in the simulation due to inability
              ;;to integrate equations correctly.
set threshold-for-aggression .5              

;; All Others

set Eff_Of_Grievance_And_Participation_On_Action 0.5    

set Government_Commitment_To_Repression 1
set Government_Strength_Regeneration_Time 5
set Grievance_Per_Repression 0.2  

set Max_Government_Strength 1
set Max_Grievance 1
set Max_Participation 1
set Max_Repression 1
set Min_Government_Strength_Adj_Time 0.5
set Min_Grievance_Adj_Time 0.5
set Min_Participation_Adj_Time 0.5
set Participation_From_Grievance 0.2
set Political_Action_Eff_On_Govt_Strength 0.2

;set Grievance_Sharing_Time 10
;set Participation_Sharing_Time 10
;set Effectiveness_Sharing_Time 10

;; create government
  create-governments round (initial-govt-density * .01 * count patches) [
    move-to one-of patches with [not any? turtles-here]
    display-government
    
;;set initial government stocks and constants
;        set Rnd_Government_Strength 0

        set Initial_Government_Strength 1 + random-float Rnd_Government_Strength
        set Government_Strength Initial_Government_Strength
  ]

  ;; create agents
  create-agents round (initial-agent-density * .01 * count patches) [
    move-to one-of patches with [not any? turtles-here]
    set active false
    display-agent
    
  ;;set initial agent stocks and constants
    
;    set Rnd_Grievance 0
;    set Rnd_Participation 0
;    set Rnd_Perc_Eff_Pol_Act 0
  
    set Initial_Grievance 0 + random-float Rnd_Grievance
    set Initial_Participation 0 + random-float Rnd_Participation
    set Initial_Perc_Eff_Of_Political_Action 0 + random-float Rnd_Perc_Eff_Pol_Act
    
    
    set A_Nrm_Grievance_Decay_Time Nrm_Grievance_Decay_Time + random-float Rnd_GDT
    set A_Participation_Decay_Time Participation_Decay_Time + random-float Rnd_PDT
    set A_Normal_Frustration_Time Normal_Frustration_Time + random-float Rnd_NFT
    set A_Effectiveness_Learning_Time Effectiveness_Learning_Time + random-float Rnd_ELT
    
    set Grievance Initial_Grievance
    set Participation Initial_Participation
    set Perceived_Effectiveness_Of_Political_Action Initial_Perc_Eff_Of_Political_Action
    
  ;; Network Diffusion

    set Effect_Of_Seeing_Others_Participation 0  
    set Effect_Of_Sharing_Grievances 0
    set Effectiveness_Of_Political_Action_By_Others 0
;set Grievance_Sharing_Time 10
;set Participation_Sharing_Time 10
;set Effectiveness_Sharing_Time 10

  
  ]

  ask agents [
    create-active-links-to other agents in-radius (vision / 3)
  ]

  ;; plot initial state of system
  my-update-plots
  update-globals
end

to go
  
; update display
  ask agents [ determine-activeness ]
  ask agents [ display-agent ]
  ask governments [ display-government ] 
 

;; FLOW EQUATIONS

  ;;set government flows  
ask governments [

;Information for Flows

set Total_Severity_Of_Political_Action sum [Severity_Of_Political_Action] of agents / count agents

set Total_Effectiveness_Of_Political_Action sum [Effectiveness_Of_Political_Action] of agents / count agents

set Govt_Strength_Decr_From_Political_Action Total_Severity_Of_Political_Action * Total_Effectiveness_Of_Political_Action * 
Political_Action_Eff_On_Govt_Strength

set Max_Govt_Strength_Decr Government_Strength / Min_Government_Strength_Adj_Time

set Repression Government_Strength * Government_Commitment_To_Repression

;Actual Flows

set Government_Strength_Increase ( Max_Government_Strength - Government_Strength) / Government_Strength_Regeneration_Time 

ifelse Govt_Strength_Decr_From_Political_Action < Max_Govt_Strength_Decr
      [ set Government_Strength_Decrease Govt_Strength_Decr_From_Political_Action ]
      [ set Government_Strength_Decrease Max_Govt_Strength_Decr ] 

]  
  ;;set agent flows
ask agents [

;Information for Flows

set Total_Government_Strength sum [Government_Strength] of governments / count governments
set Total_Repression sum [Repression] of governments / count governments

ifelse Total_Government_Strength > 0
      [ set Effectiveness_Of_Political_Action Participation / Total_Government_Strength ]
      [ set Effectiveness_Of_Political_Action 1 ]

set Frustration_Reinforcement_Rate Grievance / ( A_Normal_Frustration_Time )
           
ifelse Nrm_Grievance_Decay_Time * ( Total_Repression / Max_Repression ) > Min_Grievance_Adj_Time
      [ set Grievance_Decay_Time  A_Nrm_Grievance_Decay_Time * ( Total_Repression / Max_Repression )  ]
      [ set Grievance_Decay_Time Min_Grievance_Adj_Time ]
           

set Grievance_Incr_From_Repression Total_Repression * Grievance_Per_Repression + Frustration_Reinforcement_Rate + Effect_Of_Sharing_Grievances
           
set Max_Grievance_Increase ( Max_Grievance - Grievance ) / Min_Grievance_Adj_Time + Max_Grievance / Grievance_Decay_Time 
  
set Max_Participation_Incr ( Max_Participation - Participation ) / Min_Participation_Adj_Time + 
Max_Participation / Participation_Decay_Time 
    
set Participation_Incr_From_Grievance Grievance * Participation_From_Grievance + Effect_Of_Seeing_Others_Participation 
  
set Potential_For_Political_Action Grievance * Participation * Eff_Of_Grievance_And_Participation_On_Action
           
set Severity_Of_Political_Action Potential_For_Political_Action * ( Perceived_Effectiveness_Of_Political_Action ^ 3) 

;Actual Flows

ifelse Grievance_Incr_From_Repression < Max_Grievance_Increase
      [ set Grievance_Increase Grievance_Incr_From_Repression  ]
      [ set Grievance_Increase Max_Grievance_Increase ]

set Grievance_Decrease Grievance / Grievance_Decay_Time 

ifelse Participation_Incr_From_Grievance < Max_Participation_Incr
      [ set Participation_Increase Participation_Incr_From_Grievance  ]
      [ set Participation_Increase Max_Participation_Incr ]

set Participation_Decrease Participation / A_Participation_Decay_Time

set Learning_Eff_Of_Political_Action ( Effectiveness_Of_Political_Action - Perceived_Effectiveness_Of_Political_Action ) /
 A_Effectiveness_Learning_Time + Effectiveness_Of_Political_Action_By_Others 

] 


  ;; STOCK EQUATIONS

  ;;iterate governments stocks
ask governments [
  
  set Government_Strength Government_Strength + ( Government_Strength_Increase * DT ) - 
  ( Government_Strength_Decrease * DT ) 

]  
  
  ;;iterate agent stocks  
ask agents [
  set Grievance Grievance + ( Grievance_Increase * DT ) - ( Grievance_Decrease * DT )
 
  set Participation Participation + ( Participation_Increase * DT ) - ( Participation_Decrease * DT ) 
  
  set Perceived_Effectiveness_Of_Political_Action Perceived_Effectiveness_Of_Political_Action +
  ( Learning_Eff_Of_Political_Action * DT )
] 

;; DIFFUSION

;Important Variables...
;set Effect_Of_Seeing_Others_Participation 0  
;set Effect_Of_Sharing_Grievances 0
;set Effectiveness_Of_Political_Action_By_Others 0
;set Grievance_Sharing_Time 10
;set Participation_Sharing_Time 10
;set Effectiveness_Sharing_Time 10


; update agent Grievance via diffusion 
  ask agents [
    let recipients out-active-link-neighbors    
      ifelse any? recipients [
        let Grievance_Of_Sender Grievance
        ask recipients [

set Effect_Of_Sharing_Grievances ((Grievance_Of_Sender - Grievance) / (Grievance_Sharing_Time)) * DT
               let efg Effect_Of_Sharing_Grievances
                                  ask in-active-link-from myself [ set current-flow efg ]
                                            
         ;   ifelse Grievance_Of_Sender - Grievance >= 0
         ;    [set Effect_Of_Sharing_Grievances ((Grievance_Of_Sender - Grievance) / (Grievance_Sharing_Time)) * DT
         ;      let efg Effect_Of_Sharing_Grievances
         ;                         ask in-active-link-from myself [ set current-flow efg ]
         ;      ]
         ;    [set Effect_Of_Sharing_Grievances 0
         ;      let efg Effect_Of_Sharing_Grievances
         ;                         ask in-active-link-from myself [ set current-flow efg ]
         ;      ]
          
        ]
      ]
        
            [
               set Effect_Of_Sharing_Grievances 0
               ]   
            
  ]             
    
;]



  update-globals
  tick
  my-update-plots  

  
end

;; GOVERNMENT BEHAVIOR
to move ;; turtle procedure
    ;; move to a patch in vision; candidate patches are empty
    let targets neighborhood with
                [not any? governments-here and all? agents-here [active = false]]
    if any? targets [ move-to one-of targets ]
  
end

;; ZEALOTS
to Create_Zealot
;Pick a random agent and set its Grievance, Participation, and Percieved_Effectiveness_Of_Political_Action to new values
ask one-of agents
[
set Grievance Zealot_Grievance
set Participation Zealot_Participation
set Perceived_Effectiveness_Of_Political_Action Zealot_Perc_Eff_Of_Pol_Act
set A_Nrm_Grievance_Decay_Time 1000
set A_Normal_Frustration_Time 1000
set A_Participation_Decay_Time 1000
set A_Effectiveness_Learning_Time 1000


]  
    
end

;; VISUALIZATION

;; Visualation of Severity of Political Action
to determine-activeness
  set active ((Severity_Of_Political_Action) > threshold-for-aggression)
end

to display-agent  ;; agent procedure

  set size Grievance
  ifelse active
    [ set size Severity_Of_Political_Action * 2
      set color yellow
      set shape "fire"
      ]
    [ set size Grievance
      set color scale-color red Grievance 0 1.5
      set shape "circle"
      ]
end

to display-government
  set color cyan
  set shape "triangle" 
  set size 1

end

to update-globals
  ask governments [ set total-government-strength sum [Government_Strength] of governments * 250 ]
  ask agents [ set total-grievance sum [ Grievance ] of agents ]
  ask agents [ set total-participation sum [ Participation ] of agents ]
  ask agents [ set total-severity sum [Severity_Of_Political_Action] of agents ]
  ask agents [ set total-effectiveness sum [ Perceived_Effectiveness_Of_Political_Action ] of agents / 4 ]
end

;; PLOTTING

to my-update-plots
  let active-count count agents with [active]

  ask active-links [ 
  set color scale-color gray  (current-flow ) 0 .005 
     ]

  set-current-plot "Totals"
      set-plot-x-range (ticks - 100) ticks
      
    set-current-plot-pen "Govt Strength"
  plot total-government-strength
    set-current-plot-pen "Grievance"
  plot total-grievance  
    set-current-plot-pen "Participation"
  plot total-participation
    set-current-plot-pen "Severity of Pol Actn"
  plot total-severity
    set-current-plot-pen "Effectiveness of Pol Actn"
  plot total-effectiveness 

  
  
end
@#$#@#$#@
GRAPHICS-WINDOW
533
10
963
461
-1
-1
20.0
1
20
1
1
1
0
1
1
1
0
20
0
20
1
1
1
ticks
30

BUTTON
417
58
472
91
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
476
58
531
91
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
133
410
267
455
violent agents (flame)
count agents with [active]
3
1
11

SLIDER
0
45
205
78
vision
vision
0.0
10.0
5
.1
1
patches
HORIZONTAL

SLIDER
0
10
205
43
initial-govt-density
initial-govt-density
0.0
1.0
0.3
0.1
1
%
HORIZONTAL

MONITOR
10
410
133
455
quiet agents (circle)
count agents with [not active]
1
1
11

MONITOR
268
410
361
455
cops (triangle)
count governments
3
1
11

SLIDER
206
10
411
43
initial-agent-density
initial-agent-density
0.0
100.0
50
1.0
1
%
HORIZONTAL

PLOT
12
113
530
406
Totals
time
Vars
0.0
160.0
0.0
300.0
true
true
"" ""
PENS
"Govt Strength" 1.0 0 -13345367 true "" ""
"Grievance" 1.0 0 -2674135 true "" ""
"Participation" 1.0 0 -10899396 true "" ""
"Severity of Pol Actn" 1.0 0 -7500403 true "" ""
"Effectiveness of Pol Actn" 1.0 0 -16777216 true "" ""

SLIDER
206
45
411
78
threshold-for-aggression
threshold-for-aggression
0
2
0.5
.1
1
NIL
HORIZONTAL

CHOOSER
418
10
531
55
DT
DT
0.25 0.125 0.0625
0

SLIDER
988
26
1205
59
Grievance_Per_Repression
Grievance_Per_Repression
0
.4
0.2
.05
1
NIL
HORIZONTAL

SLIDER
988
62
1226
95
Participation_From_Grievance
Participation_From_Grievance
0
.4
0.2
.05
1
NIL
HORIZONTAL

SLIDER
990
264
1175
297
Normal_Frustration_Time
Normal_Frustration_Time
0
20
10
1
1
NIL
HORIZONTAL

SLIDER
988
99
1284
132
Eff_Of_Grievance_And_Participation_On_Action
Eff_Of_Grievance_And_Participation_On_Action
0
1
0.5
.1
1
NIL
HORIZONTAL

TEXTBOX
988
11
1199
29
Factors That Support Political Action
11
0.0
1

SLIDER
991
192
1174
225
Nrm_Grievance_Decay_Time
Nrm_Grievance_Decay_Time
0
10
5
1
1
NIL
HORIZONTAL

SLIDER
990
229
1174
262
Participation_Decay_Time
Participation_Decay_Time
0
10
5
1
1
NIL
HORIZONTAL

SLIDER
989
300
1175
333
Effectiveness_Learning_Time
Effectiveness_Learning_Time
0
10
5
1
1
NIL
HORIZONTAL

SLIDER
989
335
1249
368
Government_Strength_Regeneration_Time
Government_Strength_Regeneration_Time
0
10
5
1
1
NIL
HORIZONTAL

SLIDER
988
135
1284
168
Political_Action_Eff_On_Govt_Strength
Political_Action_Eff_On_Govt_Strength
0
.4
0.2
.05
1
NIL
HORIZONTAL

TEXTBOX
992
175
1203
193
Factors That Oppose Political Action
11
0.0
1

TEXTBOX
993
376
1189
394
Initial Stocks And Randomization
11
0.0
1

SLIDER
990
394
1214
427
Rnd_Government_Strength
Rnd_Government_Strength
0
1
0
.05
1
NIL
HORIZONTAL

SLIDER
992
432
1164
465
Rnd_Grievance
Rnd_Grievance
0
1
0
.05
1
NIL
HORIZONTAL

SLIDER
993
470
1165
503
Rnd_Participation
Rnd_Participation
0
1
0
.05
1
NIL
HORIZONTAL

SLIDER
993
507
1199
540
Rnd_Perc_Eff_Pol_Act
Rnd_Perc_Eff_Pol_Act
0
1
0
.05
1
NIL
HORIZONTAL

TEXTBOX
376
441
526
459
Diffusion
11
0.0
1

TEXTBOX
807
466
957
484
Collective Action -- Zealots
11
0.0
1

SLIDER
366
463
571
496
Grievance_Sharing_Time
Grievance_Sharing_Time
0
20
10
1
1
NIL
HORIZONTAL

BUTTON
842
485
959
518
NIL
Create_Zealot
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
627
466
799
499
Zealot_Grievance
Zealot_Grievance
0
1
1
.1
1
NIL
HORIZONTAL

SLIDER
627
503
802
536
Zealot_Participation
Zealot_Participation
0
1
1
.1
1
NIL
HORIZONTAL

SLIDER
628
545
851
578
Zealot_Perc_Eff_Of_Pol_Act
Zealot_Perc_Eff_Of_Pol_Act
0
1
1
.1
1
NIL
HORIZONTAL

SLIDER
11
476
359
509
Eff_Of_Grievance_And_Participation_On_Action
Eff_Of_Grievance_And_Participation_On_Action
0
1
0.5
.1
1
NIL
HORIZONTAL

SLIDER
1177
193
1349
226
Rnd_GDT
Rnd_GDT
0
10
0
1
1
NIL
HORIZONTAL

SLIDER
1176
263
1348
296
Rnd_NFT
Rnd_NFT
0
20
0
1
1
NIL
HORIZONTAL

SLIDER
1177
231
1349
264
Rnd_PDT
Rnd_PDT
0
10
0
1
1
NIL
HORIZONTAL

SLIDER
1178
299
1350
332
Rnd_ELT
Rnd_ELT
0
10
0
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This is a model of Political Opportunity Theory (PO) and Collective Action Theory (CA).

## HOW IT WORKS

Each "agent," or member of the general population (shown usually as a CIRCLE), has some Grievance with the government. This is shown by the color of the circle shapes: brighter red = more Grievance.

Each agent has Participation in some movement's or group's political action against the government. This is shown as the size of the circle. Bigger = higher level of participation in the cause.

The propensity to violence is a nonlinear (cubic) product of Grievance, Participation, and the Percieved Effectivenss of Political Action. The ideal rebel is aggrieved, participates in political movements/groups, and believes there is an opportunity for his or her political action to be successful against the government.

## HOW TO USE IT

Use the sliders to pick the initial settings for the model. 

Click SETUP to initialize the population. Click GO to begin the simulation.

As the simulation runs, you can adjust the various sliders.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fire
false
0
Polygon -7500403 true true 151 286 134 282 103 282 59 248 40 210 32 157 37 108 68 146 71 109 83 72 111 27 127 55 148 11 167 41 180 112 195 57 217 91 226 126 227 203 256 156 256 201 238 263 213 278 183 281
Polygon -955883 true false 126 284 91 251 85 212 91 168 103 132 118 153 125 181 135 141 151 96 185 161 195 203 193 253 164 286
Polygon -2674135 true false 155 284 172 268 172 243 162 224 148 201 130 233 131 260 135 282

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

person active
false
0
Polygon -13791810 true false 135 90 150 105 135 165 150 180 165 165 150 105 165 90
Polygon -2674135 true false 195 135 240 30 210 15 165 120
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -2674135 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -2674135 true false 105 135 60 30 90 15 135 120
Polygon -6459832 true false 195 15 270 60 270 75 195 30

person jailed
false
0
Circle -7500403 true true 110 5 80
Polygon -16777216 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -16777216 true false 195 90 210 150 195 180 165 105
Polygon -16777216 true false 105 90 90 150 105 180 135 105

person quiet
false
0
Polygon -13791810 true false 135 90 150 105 135 165 150 180 165 165 150 105 165 90
Polygon -1184463 true false 195 90 240 195 210 210 165 105
Circle -7500403 true true 110 5 80
Rectangle -7500403 true true 127 79 172 94
Polygon -1184463 true false 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -1 true false 100 210 130 225 145 165 85 135 63 189
Polygon -13791810 true false 90 210 120 225 135 165 67 130 53 189
Polygon -1 true false 120 224 131 225 124 210
Line -16777216 false 139 168 126 225
Line -16777216 false 140 167 76 136
Polygon -1184463 true false 105 90 60 195 90 210 135 105

person soldier
false
10
Rectangle -7500403 true false 127 79 172 94
Polygon -13345367 true true 105 90 60 195 90 210 135 105
Polygon -13345367 true true 195 90 240 195 210 210 165 105
Circle -7500403 true false 110 5 80
Polygon -13345367 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Polygon -6459832 true false 120 90 105 90 180 195 180 165
Line -6459832 false 109 105 139 105
Line -6459832 false 122 125 151 117
Line -6459832 false 137 143 159 134
Line -6459832 false 158 179 181 158
Line -6459832 false 146 160 169 146
Rectangle -6459832 true false 120 193 180 201
Polygon -6459832 true false 122 4 107 16 102 39 105 53 148 34 192 27 189 17 172 2 145 0
Polygon -16777216 true false 183 90 240 15 247 22 193 90
Rectangle -6459832 true false 114 187 128 208
Rectangle -6459832 true false 177 187 191 208

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 15 0 270 300 270

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0beta1
@#$#@#$#@
setup
repeat 5 [ go ]
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

small-arrow-link
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 120 180
Line -7500403 true 150 150 180 180

@#$#@#$#@
0
@#$#@#$#@
